@@ -10,6 +10,7 @@ from yafowil.compound import (
     compound_renderer,
 )
 
+
 def actions_renderer(widget, data):
     tag = data.tag
     actions = list()
@@ -18,13 +19,16 @@ def actions_renderer(widget, data):
             class_ = 'dict_row_%s' % key
             action = tag('a', '&#160;', href='#', class_=class_)
             actions.append(action)
-    return tag('div', *actions, class_='dict_actions')
+    # XXX: bypass for py24 (and py25?). py26 can deal with kw after *actions
+    kw = dict(class_='dict_actions')
+    return tag('div', *actions, **kw)
 
 factory.doc['widget']['dict_actions'] = UNSET # dont document internal widget
 factory.register('dict_actions',
                  [],
                  [actions_renderer])
 
+
 def dict_builder(widget, factory):
     table = widget['table'] = factory(
         'table',
@@ -59,6 +63,7 @@ def dict_builder(widget, factory):
         )
     table['body'] = factory('tbody', props={'structural': True})
 
+
 def dict_renderer(widget, data):
     static = widget.attrs['static']
     table = widget['table']
@@ -104,11 +109,13 @@ def dict_renderer(widget, data):
             )
         i += 1
 
+
 def raise_extraction_error(widget):
     if isinstance(widget.attrs['required'], basestring):
         raise ExtractionError(widget.attrs['required'])
     raise ExtractionError(widget.attrs['required_message'])
 
+
 def extract_static(data, basename):
     request = data.request
     ret = odict()
@@ -123,6 +130,7 @@ def extract_static(data, basename):
         break
     return ret
 
+
 def extract_dynamic(data, basename):
     request = data.request
     ret = odict()
@@ -139,6 +147,7 @@ def extract_dynamic(data, basename):
         break
     return ret
 
+
 def dict_extractor(widget, data):
     static = widget.attrs['static']
     body = widget['table']['body']
